;; Generated package description from sapling.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "sapling" "0.2.1.0.20260820.0" "Magit-like interface for Sapling" '((emacs "26.1")) :commit "5948e50ce95c7302bf91eac4d341fcd628581b3d" :authors '(("Swithin Chan" . "swithinchan@yahoo.com.hk")) :maintainer '("Swithin Chan" . "swithinchan@yahoo.com.hk") :keywords '("tools" "vc") :url "https://github.com/swithinchan/sapling/")
